# The xPack OpenOCD

The **xPack OpenOCD** is a cross-platform binary distribution of OpenOCD, the Open On-Chip Debugger, an open source project hosted on  SourceForge.

The OpenOCD project maintainers recommend that end-users compile it using the latest version of the source code available from the repository. OpenOCD is a rolling distribution, and currently there are no special stable branches or tags and there are no clear release dates for future versions.

If for GNU/Linux users compiling projects is common, Windows users do not have an easy way of building OpenCOD from sources, and elaborate build environments must be installed, making the whole process impractical.

If you are not interested in building from sources, and appreciate a better integration with the environments like Eclipse, please feel free to use the **xPack OpenOCD** binaries, and preferably install them in the default locations.

For more details, please read the corresponding release pages:

- <https://xpack.github.io/openocd/releases/>
- <http://openocd.org>

Thank you for using open source software,

Liviu Ionescu
